@@ -395,16 +395,16 @@ class B2World:
         # to makes sure we have the correct shape
         self._all_desired_torques = copy.deepcopy(all_torques)
 
-        # overwritting states of balls if asked to do
-        # so
+        # overwritting states of balls if asked to do so
         if mirroring_ball_states:
             for index,item in mirroring_ball_states.items():
                 ball = self.balls[index]
-                ball.position.x = item.position[0]
-                ball.position.y = item.position[1]
-                ball.linearVelocity = item.linear_velocity
+                ball.position = np.array(item.position)
+                ball.angle = item.angle
+                ball.linearVelocity = np.array(item.linear_velocity)
                 ball.angularVelocity = item.angular_velocity
-        
+                ball.bullet = True
+                
         # mirroring info can be used to force the robot(s) to move
         # according to data passed to the step function rather than
         # by applying the physics. Typically to mirror another robot.
@@ -465,8 +465,10 @@ class B2World:
         # rather than applying control)
         if mirroring_robot_states :
             for index,robot_state in mirroring_robot_states.items():
-                # NOTE: I assume that mirroring_info gives a robot state. This state can easily be obtained
-                # by calling the method get_state of a B2Robot. TODO: Adapt mirroring_info
+                # NOTE: I assume that mirroring_info gives a robot state.
+                #       This state can easily be obtained
+                #       by calling the method get_state of a B2Robot.
+                #       TODO: Adapt mirroring_info
                 self.robots[index].set_state(robot_state)
 
         # updating the world state
